@@ -1,4 +1,6 @@
+import sys
 import bftool
 
 if __name__ == "__main__":
+    sys.argv[0] = "bftool"
     bftool.Runner().run()
